diff roundup/cgi/templating.py @ 5927:a2a7860502fa

Fix lookupIds for try_id_parsing off Fixes my patch in commit 716d50585c8d.
author Ralf Schlatterbeck <rsc@runtux.com>
date Wed, 16 Oct 2019 12:50:37 +0200
parents fe96015445e9
children 33914dd1160f
line wrap: on
line diff
--- a/roundup/cgi/templating.py	Tue Oct 15 16:23:06 2019 +0200
+++ b/roundup/cgi/templating.py	Wed Oct 16 12:50:37 2019 +0200
@@ -384,8 +384,8 @@
     cl = db.getclass(prop.classname)
     l = []
     for entry in ids:
-        # Do not look up numeric IDs
-        if num_re.match(entry):
+        # Do not look up numeric IDs if try_id_parsing
+        if prop.try_id_parsing and num_re.match(entry):
             l.append(entry)
             continue
         if do_lookup:

Roundup Issue Tracker: http://roundup-tracker.org/